@@ -1,8 +1,7 @@
 import os
-import sys
 from pathlib import Path
 from textwrap import dedent
-from typing import NewType
+from typing import NewType, Optional
 
 DEFAULT_PIPX_HOME = Path.home() / ".local/pipx"
 DEFAULT_PIPX_BIN_DIR = Path.home() / ".local/bin"
@@ -28,6 +27,8 @@ EXIT_CODE_UNINSTALL_VENV_NONEXISTENT = ExitCode(1)
 EXIT_CODE_UNINSTALL_ERROR = ExitCode(1)
 EXIT_CODE_REINSTALL_VENV_NONEXISTENT = ExitCode(1)
 
+pipx_log_file: Optional[Path] = None
+
 
 def is_windows() -> bool:
     try:
@@ -40,24 +41,6 @@ def is_windows() -> bool:
 
 WINDOWS: bool = is_windows()
 
-
-def strtobool(val: str) -> bool:
-    val = val.lower()
-    if val in ("y", "yes", "t", "true", "on", "1"):
-        return True
-    elif val in ("n", "no", "f", "false", "off", "0"):
-        return False
-    else:
-        return False
-
-
-def use_emjois() -> bool:
-    platform_emoji_support = not is_windows() and sys.getdefaultencoding() == "utf-8"
-    return strtobool(str(os.getenv("USE_EMOJI", platform_emoji_support)))
-
-
-emoji_support = use_emjois()
-
 completion_instructions = dedent(
     """
 Add the appropriate command to your shell's config file
